/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

<Ejemplo Capitulo 3: Ejemplo utilizando wxStaticText, wxTextCtrl, wxButton y wxMenu.>
Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
*/


#ifndef _CHAPTER_03_H_
#define _CHAPTER_03_H_

#include <wx/wx.h>

/**
 * @brief Clase que modela la aplicacion. Esta compuesta por <i>Frames</i>.
 * @author David Casas Molina
 * @date 17 de enero de 2010
 ^ @note Parte del proyecto wxTutorial.
 */
class MyApp : public wxApp 
{
public:
   /**
    * Metodo virtual que arranca la aplicacion.
    * @return Booleano que indica si la aplicacion se ha ejecutado con exito o no.
    */
   virtual bool OnInit();
};


/**
 * @brief Clase que modela un <i>Frames</i>. En ella se definen todos los componentes queramos que contenga.
 * @author David Casas Molina
 * @date 17 de enero de 2010
 ^ @note Parte del proyecto wxTutorial.
 */
class MyFrame : public wxFrame
{
public:
   /**
    * Constructor de la clase MyFrame.
    * @param title Titulo del <i>Frames</i>.
    */
   MyFrame(const wxString& title);
   /**
    * Manejador del evento <code>OnShow()</code>.
    * @param event Referencia al comando del evento <code>OnShow()</code>.
    */
   void OnShow(wxCommandEvent& event);
   /**
    * Manejador del evento <code>OnQuit()</code>.
    * @param event Referencia al comando del evento <code>OnQuit()</code>.
    */
   void OnExit(wxCommandEvent& event);
private:
   /**
    * Puntero a un MenuBar, que utilizaremos para integrar el menu.
    */
    wxMenuBar *mbMenu;
   /**
    * Puntero a un Menu, que utilizaremos para las funcionalidades.
    */
    wxMenu *mnMenu;
   /**
    * Puntero a un boton, que utilizaremos para mostrar el texto.
    */
    wxButton *btnShow;
   /**
    * Puntero a un boton, que utilizaremos para salir del programa.
    */
    wxButton *btnExit;
   /**
    * Puntero a un StaticText, que utilizaremos para que muestre el texto.
    */
    wxStaticText *lblShow;
   /**
    * Puntero a un TextCtrl, que utilizaremos para introducir el texto.
    */
    wxTextCtrl *tcText;
   /**
    * Declaracion de la tabla de eventos del <i>Frame</i>.
    */
   DECLARE_EVENT_TABLE()
};

DECLARE_APP(MyApp)

#endif
