
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

< wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
*/

#include "dexp.h"
#include "path.h"

enum identificadores {
  ID_ChangeChapter,
  ID_ChangeSubChapter,
  ID_Complete,
  ID_Example,
  ID_Add,
  ID_Delete,
};

BEGIN_EVENT_TABLE(DialogExport, wxDialog)
EVT_COMBOBOX(ID_ChangeChapter, DialogExport::OnChangeChapter)
EVT_BUTTON(ID_Add, DialogExport::OnAddFile)
EVT_BUTTON(ID_Delete, DialogExport::OnDeleteFile)
EVT_CHECKBOX(ID_Complete, DialogExport::OnCheckedComplete)
END_EVENT_TABLE()


DialogExport::DialogExport(wxWindow* parent, wxWindowID id, const wxString& title):
wxDialog(parent, id, title, wxDefaultPosition, wxSize(600,220))
{
  // Centramos la ventana de diálogo en la pantalla.
  Centre();

  cancel = new wxButton(this, wxID_CANCEL, wxString::FromUTF8("Cancelar"), wxPoint(380, 160));
  ok = new wxButton(this, wxID_OK, wxString::FromUTF8("Aplicar"), wxPoint(500, 160));

  labelchapter = new wxStaticText(this, wxID_ANY, wxString::FromUTF8("Selecciona los artículos a exportar..."),
				  wxPoint(30,20), wxSize(310,30));
  
  wxString aux[7] = {wxString::FromUTF8("1. Introducción."),
		     wxString::FromUTF8("2. Conceptos Básicos."),
		     wxString::FromUTF8("3. Componentes Básicos."),
		     wxString::FromUTF8("4. Componentes de Imagen."),
		     wxString::FromUTF8("5. Componentes de Elección."),
		     wxString::FromUTF8("6. Componentes Contenedores."),
		     wxString::FromUTF8("7. Componentes de Diálogo.")};
  
  chapter = new wxComboBox(this, ID_ChangeChapter, wxString::FromUTF8("Selecciona un capítulo.."), wxPoint(20,50),
			   wxSize(260, 30),7, aux, wxCB_DROPDOWN | wxCB_READONLY );
  
  subchapter = new wxComboBox(this, ID_ChangeSubChapter, wxString::FromUTF8("Selecciona un subcapítulo..."),
			      wxPoint(20,100), wxSize(260,30));  

  listfile = new wxListBox(this, wxID_ANY, wxPoint(360, 30), wxSize(220,100));
  
  wxInitAllImageHandlers();
  wxImage imag = wxImage(48,48);
  
  imag.LoadFile(Path::GetPathPicture(2), wxBITMAP_TYPE_PNG);
  imag.Rescale(25,25);
  add = new wxBitmapButton(this, ID_Add, wxBitmap(imag), wxPoint(300, 40));

  imag.LoadFile(Path::GetPathPicture(1), wxBITMAP_TYPE_PNG);
  imag.Rescale(25,25);
  del = new wxBitmapButton(this, ID_Delete, wxBitmap(imag), wxPoint(300, 90));
  
  complete = new wxCheckBox(this, ID_Complete, wxString::FromUTF8("Exportar todo el contenido."), wxPoint(30,145));
  complete->Enable(true);
  example = new wxCheckBox(this, ID_Example, wxString::FromUTF8("Exportar junto con los ejemplos."), wxPoint(30, 165)); 
  example->Enable(false);
}

void DialogExport::OnChangeChapter(wxCommandEvent& event)
{
  subchapter->Clear();
  subchapter->SetValue(wxString::FromUTF8("Selecciona un subcapítulo..."));

  switch(chapter->GetCurrentSelection()){
  case 0: subchapter->Insert(wxString::FromUTF8("¿Qué son las bibliotecas gráficas?."),0);
          subchapter->Insert(wxString::FromUTF8("¿Cómo programar en wxWidgets?."),1);
	  subchapter->Insert(wxString::FromUTF8("El entorno wxDevC++."),2);
	  subchapter->Insert(wxString::FromUTF8("Otras bibliotecas gráficas."),3);
    break;
  case 1: subchapter->Insert(wxString::FromUTF8("Componentes."),0);
          subchapter->Insert(wxString::FromUTF8("Tipos de datos."),1);
	  subchapter->Insert(wxString::FromUTF8("Eventos."),2);
	  subchapter->Insert(wxString::FromUTF8("Primer Ejemplo."),3);
    break;
  case 2: subchapter->Insert(wxString::FromUTF8("wxApp, wxFrame, wxButton."),0);
          subchapter->Insert(wxString::FromUTF8("wxStaticText, wxEdit."),1);
	  subchapter->Insert(wxString::FromUTF8("wxMenu."),2);
    break;
  case 3: subchapter->Insert(wxString::FromUTF8("Imagen"),0);
    break;
  case 4: subchapter->Insert(wxString::FromUTF8("wxChoice, wxComboBox, wxListBox."),0);
          subchapter->Insert(wxString::FromUTF8("wxCheckBox, wxRadioBox."),1);
    break;
  case 5: subchapter->Insert(wxString::FromUTF8("wxPanel."),0);
          subchapter->Insert(wxString::FromUTF8("wxNotebook."),1);
	  subchapter->Insert(wxString::FromUTF8("wxHtmlWindow."),2);
    break;
  case 6: subchapter->Insert(wxString::FromUTF8("wxDialog."),0);
          subchapter->Insert(wxString::FromUTF8("Diálogos de entrada de datos."),1); 
          subchapter->Insert(wxString::FromUTF8("Diálogos de salida de datos."),2);
	  subchapter->Insert(wxString::FromUTF8("Diálogos de ficheros."),3);
    break;
  }

}

void DialogExport::OnAddFile(wxCommandEvent& event)
{
  if(chapter->GetCurrentSelection() != -1 && subchapter->GetCurrentSelection() != -1)
    listfile->Append(chapter->GetValue()+wxString::FromUTF8(" ")+subchapter->GetValue());
}

void DialogExport::OnDeleteFile(wxCommandEvent& event)
{
    for(size_t i =0; i< listfile->GetCount(); i++){
      if(listfile->IsSelected(i))
	listfile->Delete(i);
    }
  
}

void DialogExport::OnCheckedComplete(wxCommandEvent& event)
{
  if(complete->IsChecked()){
    example->Enable(true);
    chapter->Enable(false);
    subchapter->Enable(false);
    add->Enable(false);
    del->Enable(false);
    listfile->Enable(false);
  }
  else {
    example->Enable(false);
    chapter->Enable(true);
    subchapter->Enable(true);
    add->Enable(true);
    del->Enable(true);
    listfile->Enable(true);
  }
  
}

void DialogExport::Process()
{
  wxFileDialog savefile(this, wxString::FromUTF8("Exportar archivo:"),
					    wxString::FromUTF8(""), wxString::FromUTF8(""),
					    wxString::FromUTF8("*.pdf"), wxFD_SAVE);
  // las rutas d los ficheros pdf estarán en la clase Path.

  if(complete->IsChecked()){
    if(savefile.ShowModal() == wxID_OK) {
      wxString getpath = savefile.GetPath();
    
#ifdef __WXGTK__
      getpath = getpath+wxString::FromUTF8(".pdf");
#endif
        if(example->IsChecked()) {// completo con ejemplos.
	      wxCopyFile(Path::GetPDF(0), getpath, true);
        }
        else {// completo sin ejemplos. 
	      wxCopyFile(Path::GetPDF(1), getpath, true);
        }
      //}
    }
  }
  
  else {
    for(size_t i=0; i<listfile->GetCount(); i++){
      //if(listfile->IsSelected(i)){
      savefile.SetMessage(wxString::FromUTF8("Guardar: ")+listfile->GetString(i));
      if(savefile.ShowModal()==wxID_OK){
        wxString getpath = savefile.GetPath();
      
#ifdef __WXGTK__
        getpath = getpath+wxString::FromUTF8(".pdf");
#endif
        //if(savefile->GetReturnCode() == wxID_OK)
	      wxCopyFile(Path::GetPDF(listfile->GetString(i)), getpath);
      //}
      }
    }
  }
}
