
/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.

 * < wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
 * Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
 */

#ifndef _DIALOGEXPORT_
#define _DIALOGEXPORT_

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#include <wx/wx.h>
#include <wx/dialog.h>

/**
 * @brief Definición del diálogo para exportar
 * los artículos del tutorial y/o los códigos
 * de los ejemplos.
 *
 * @author Rosa María Durante Lerate
 * @note Parte del proyecto wxTutorial!
 */
class DialogExport: public wxDialog
{
 public:

  /**
   * @brief Constructor de la clase. 
   * @param parent Puntero de tipo wxWindow siendo éste
   * el componente donde se ha llamado al diálogo.
   * @param id Identificador del diálogo.
   * @param title Título del diálogo.
   */
  DialogExport(wxWindow* parent, wxWindowID id, const wxString& title);
  /**
   * @brief Función que define el comportamiento para el evento 
   * de cambiar capítulo en el diálogo.
   * @param event Evento producido en la aplicación.
   */
  void OnChangeChapter(wxCommandEvent& event);

  /**
   * @brief Función que define el comportamiento para el evento
   * de añadir artículos a la lista para su exportación a PDF.
   * @param event Evento producido en la aplicación.
   */
  void OnAddFile(wxCommandEvent& event);
  
  /**
   * @brief Función que define el comportamiento para el evento
   * de eliminar artículos de la lista para su exportación a PDF.
   * @param event Evento producido en la aplicación.
   */
  void OnDeleteFile(wxCommandEvent& event);

  /**
   * @brief Función que define el comportamiento para el evento
   * de marcar el cuadro para exportar todo el contenido.
   * @param event Evento producido en la aplicación.
   */
  void OnCheckedComplete(wxCommandEvent& event);

  /**
   * @brief Función por el cual, una vez se acepte
   * en el diálogo se procesa las opciones elegidas
   * por el usuario.
   */
  void Process();

 private:
  wxButton *ok;
  wxButton *cancel;
  
  wxBitmapButton *add;
  wxBitmapButton *del;
  wxStaticText *labelchapter;
  wxComboBox *chapter;
  wxStaticText *listsubchapter;
  wxComboBox *subchapter;
  wxStaticText *labellistfiles;
  wxListBox *listfile;
  
  wxCheckBox *complete;
  wxCheckBox *example;

  DECLARE_EVENT_TABLE()
};

#endif
