
/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.

 * < wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
 * Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
 */

#ifndef _DIALOGIMAGE_
#define _DIALOGIMAGE_

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#include <wx/wx.h>
#include <wx/dialog.h>

/**
 * @brief Definición del diálogo para
 * visualizar imágenes.
 *
 * @author Rosa María Durante Lerate
 * @note Parte del proyecto wxTutorial!
 */
class DialogImage : public wxDialog
{
 public:
  /**
   * @brief Constructor de la clase
   * @param parent Puntero de tipo wxWindow siendo éste
   * el componente donde se ha llamado al diálogo.
   * @param id Identificador del diálogo.
   * @param title Título del diálogo.
   * @param example Número del ejemplo del que hay que
   * cargar las imágenes.
   */
  DialogImage(wxWindow* parent, wxWindowID id, const wxString& title, size_t example);
  
  /**
   * @brief Función que define el comportamiento para
   * pasar a la anterior imagen del ejemplo.
   * @param event Evento producido en la aplicación.
   */
  void OnLastImage(wxCommandEvent& event);
  
  /**
   * @brief Función que define el comportamiento para
   * pasar a la siguiente imagen del ejemplo.
   * @param event Evento producido en la aplicación.
   */
  void OnNextImage(wxCommandEvent& event);

 private:

  void LoadImage(size_t numimage);

  wxImage image;
  wxStaticBitmap *showimage;

  wxButton *cancel;

  wxStaticText *textimage;

  size_t nimag;
  size_t nexample;
  size_t imagenow;

  wxBitmapButton *nextimage;
  wxBitmapButton *lastimage;
  DECLARE_EVENT_TABLE()
};

#endif
