
/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.

 * < wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
 * Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
 */

#ifndef _DIALOGSHOW_
#define _DIALOGSHOW_

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#include <wx/wx.h>
#include <wx/dialog.h>

/**
 * @brief Definición del diálogo para mostar
 * los artículos de la aplicación.
 *
 * @author Rosa María Durante Lerate
 * @note Parte del proyecto wxTutorial!
 */
class DialogShowChapter : public wxDialog
{
 public:

  /**
   * @brief Constructor de la clase.
   * @param parent Puntero de tipo wxWindow siendo éste
   * el componente donde se ha llamado al diálogo.
   * @param id Identificador del diálogo.
   * @param title Título del diálogo.
   */
  DialogShowChapter(wxWindow* parent,  wxWindowID id, const wxString& title);

  /**
   * @brief Función que define el comportamiento para 
   * el evento de cambiar de capítulo en el diálogo.
   * @param event Evento producido en la aplicación.
   */
  void OnChangeChapter(wxCommandEvent& event);
  
  /**
   * @brief Función por el cual, una vez el usuario acepte
   * el diálogo, procesa las opciones elegidas por el usuario.
   * @return Devuelve el número del artículo a visualizar.
   */
  size_t Process();

 private:
  wxButton *ok;
  wxButton *cancel;
  wxStaticText *labelchapter;
  wxComboBox *chapter;
  wxComboBox *subchapter;

  DECLARE_EVENT_TABLE()
};


/**
 * @brief Definición de la clase para mostrar
 * el código fuente de los ejemplos de la aplicación.
 *
 * @author Rosa María Durante Lerate
 * @note Parte del proyecto wxTutorial!
 */
class DialogShowExample : public wxDialog
{
 public:

  /**
   * @brief Constructor de la clase.
   * @param parent Puntero de tipo wxWindow siendo éste
   * el componente donde se ha llamado al diálogo.
   * @param id Identificador del diálogo.
   * @param title Título del diálogo.
   */
  DialogShowExample(wxWindow* parent,  wxWindowID id, const wxString& title);

  /**
   * @brief Función que define el comportamiento 
   * para el evento de cambiar el ejemplo de la
   * aplicación a mostar en el diálogo.
   * @param event Evento producido en la aplicación.
   */
  void OnChangeChapter(wxCommandEvent& event);

  /**
   * @brief Función por el cual, una vez que se 
   * acepte el diálogo, procesa las opciones elegidas
   * por el usuario.
   * @return Devuelve el número del código a mostrar.
   */
  int Process();

  /**
   * @brief Función de comprobación del ejemplo a visualizar.
   * @return Devuelve el número del ejemplo del que se
   * quiere visualizar alguno de sus códigos.
   */
  int Example();
 private:
  wxButton *ok;
  wxButton *cancel;
  wxStaticText *labelchapter;
  wxComboBox *chapter;
  wxListBox *subchapter;

  wxCheckBox *image;
  DECLARE_EVENT_TABLE()
};

#endif
