
/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.

 * < wxTutorial! Tutorial para el aprendizaje de las bibliotecas wxWidgets.>
 * Copyright (C) 2009, {Rosa Maria Durante, David Casas, Jose Galvan}
 */

#ifndef _PATH_
#define _PATH_

#ifdef __BORLANDC__
#pragma hdrstop
#endif

#include <wx/wx.h>

/**
 * @brief Definición de todos las rutas 
 * donde se encuentran los ficheros externos
 * y otras características.
 *
 * @author Rosa María Durante Lerate
 * @note Parte del proyecto wxTutorial!
 */
class Path {
 public:
  /**
   * @brief Rutas de los iconos de la aplicación.
   * @param index Número del icono.
   * @return Devuelve una cadena conteniendo la ruta.
   */
  static const wxString& GetPathPicture(size_t index);
  /**
   * @brief Rutas de los códigos a visualizar.
   * @param index Número del código.
   * @return Devuelve una cadena conteniendo la ruta.
   */
  static const wxString& GetPathCode(size_t index);
  /**
   * @brief Rutas de los artículos a visualizar.
   * @param index Número del artículo.
   * @return Devuelve una cadena conteniendo la ruta.
   */
  static const wxString& GetPathHtml(size_t index);
  /**
   * @brief Ruta de los artículos en PDF.
   * @param index Número del artículo.
   * @return Devuelve una cadena conteniendo la ruta.
   */
  static const wxString& GetPDF(size_t index);
  /**
   * @brief Ruta de los artículos en PDF.
   * @param s Cadena con el identificador del
   * artículo.
   * @return Devuelve una cadena conteniendo la ruta.
   */
  static const wxString& GetPDF(const wxString& s);
  /**
   * @brief Ruta de las imágenes que se muestran en 
   * la aplicación.
   * @param index Número de la imagen.
   * @return Devuelve una cadena conteniendo la ruta.
   */
  static const wxString& GetPathImage(size_t index);
  /**
   * @brief Información conjunta con la imagen a mostrar.
   * @param index. Número de la imagen/información.
   * @return Devuelve una cadena conteniendo la información.
   */
  static const wxString& GetCaptionImage(size_t index);
  /**
   * @brief Ruta de los ejecutables de los ejemplos.
   * @param index. Número del ejemplo.
   * @return Devuelve una cadena conteniendo la ruta.
   */
  static const wxString& GetPathExe(size_t index);
  /**
   * @brief Información de la licencia de la aplicación.
   * @return Devuelve una cadena conteniendo la licencia.
   */
  static const wxString& GetLicense();
 
  /**
   * @brief Vector de cadenas que contienen las rutas 
   * de los iconos de la aplicación.
   */
  static wxString pictures[8];
  /**
   * @brief Vector de cadenas que contienen las rutas 
   * de los artículos a visualizar de la aplicación.
   */
  static wxString html[25];
  /**
   * @brief Vector de cadenas que contienen las rutas
   * de los artículos en PDF de la aplicación.
   */
  static wxString pdf[25];
  /**
   * @brief Cadena que contiene la licencia de la aplicación.
   */
  static wxString license;
  /**
   * @brief Vector de cadenas que contiene las rutas
   * de los códigos que se visualizan en la aplicación.
   */
  static wxString code[30];
  /**
   * @brief Vector de cadenas que contiene las rutas
   * de las imágenes que se visualizan en la aplicación.
   */
  static wxString image[50];
  /**
   * @brief Vector de cadenas que contiene la información
   * de las imágenes que se visualizan.
   */
  static wxString caption[50];
  /**
   * @brief Vector de cadenas que contiene las rutas
   * de los ejecutables de los ejemplos.
   */
  static wxString executable[8];
};

#endif
